﻿using Quartz.Impl;
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;

namespace Quartz.NET.Apply
{
    public class ConsoleWriteJobShowDatetime : IJob
    {
        public Task Execute(IJobExecutionContext context)
        {
            Console.WriteLine($"任务执行时间:{DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss")}");
            return Task.CompletedTask;
        }
    }
    public static class QuartzRunJob
    {
        public static async Task RunJob()
        {
            ISchedulerFactory schedulerFactory = new StdSchedulerFactory();
            IScheduler scheduler = await schedulerFactory.GetScheduler();

            DateTimeOffset startTime = DateBuilder.NextGivenSecondDate(DateTime.Now, 1);

            IJobDetail job = JobBuilder.Create<ConsoleWriteJobShowDatetime>()
                             .WithIdentity("ConsoleWriteJobShowDatetime","job")
                             .Build();

            ITrigger trigger = TriggerBuilder.Create()
                                       .StartAt(startTime)
                                       .WithIdentity("ConsoleWriteJobShowDatetime", "job")
                                       .WithSimpleSchedule(x=>x.WithIntervalInSeconds(1).RepeatForever())
                                       .Build();

            await scheduler.ScheduleJob(job, trigger);
            await scheduler.Start();
        }
    }
}
